==> decoupler-1.0.0.tar.gz: decoupler-1.0.0/README.md <==
# decoupler - Ensemble of methods to infer biological activities <img src="https://github.com/saezlab/decoupleR/blob/master/inst/figures/logo.svg?raw=1" align="right" width="120" class="no-scaled-link" />
<!-- badges: start -->
![main_build](https://github.com/saezlab/decoupler-py/actions/workflows/python-package.yml/badge.svg)
[![GitHub issues](https://img.shields.io/github/issues/saezlab/decoupler-py.svg)](https://github.com/saezlab/decoupler-py/issues/)
<!-- badges: end -->

**decoupler** is a package containing different statistical methods to extract biological activities from omics data within a unified framework.
This is its faster and memory efficient Python implementation, for the R version go [here](https://github.com/saezlab/decoupleR).

For further information and example tutorials, please check our [documentation](https://decoupler-py.readthedocs.io/en/latest/index.html).

If you have any question or problem do not hesitate to open an [issue](https://github.com/saezlab/decoupler-py/issues).

## Installation

To install the latest stable version run:
```
pip install decoupler
```

Alternatively, to stay up-to-date with the newest version, run: 
```
pip install git+https://github.com/saezlab/decoupler-py.git
```

## Citation

Badia-i-Mompel P., Vélez J., Braunger J., Geiss C., Dimitrov D.,
Müller-Dott S., Taus P., Dugourd A., Holland C.H., Ramirez Flores R.O.
and Saez-Rodriguez J. 2021. decoupleR: Ensemble of computational methods
to infer biological activities from omics data. bioRxiv.
<https://doi.org/10.1101/2021.11.04.467271>

==> decoupler-1.1.0.tar.gz: decoupler-1.1.0/README.md <==
# decoupler - Ensemble of methods to infer biological activities <img src="https://github.com/saezlab/decoupleR/blob/master/inst/figures/logo.svg?raw=1" align="right" width="120" class="no-scaled-link" />
<!-- badges: start -->
![main_build](https://github.com/saezlab/decoupler-py/actions/workflows/python-package.yml/badge.svg)
[![GitHub issues](https://img.shields.io/github/issues/saezlab/decoupler-py.svg)](https://github.com/saezlab/decoupler-py/issues/)
<!-- badges: end -->

**decoupler** is a package containing different statistical methods to extract biological activities from omics data within a unified framework.
This is its faster and memory efficient Python implementation, for the R version go [here](https://github.com/saezlab/decoupleR).

For further information and example tutorials, please check our [documentation](https://decoupler-py.readthedocs.io/en/latest/index.html).

If you have any question or problem do not hesitate to open an [issue](https://github.com/saezlab/decoupler-py/issues).

## Installation

To install the latest stable version run:
```
pip install decoupler
```

Alternatively, to stay up-to-date with the newest version, run: 
```
pip install git+https://github.com/saezlab/decoupler-py.git
```

## License
Footprint methods inside decoupler can be used for academic or commercial purposes, except `viper` which holds a non-commercial license. 

The data redistributed by OmniPath does not have a license, each original resource carries their own. 
[Here](https://omnipathdb.org/info) one can find the license information of all the resources in OmniPath.

## Citation

Badia-i-Mompel P., Vélez Santiago J., Braunger J., Geiss C., Dimitrov D.,
Müller-Dott S., Taus P., Dugourd A., Holland C.H., Ramirez Flores R.O.
and Saez-Rodriguez J. 2022. decoupleR: Ensemble of computational methods
to infer biological activities from omics data. Bioinformatics Advances.
<https://doi.org/10.1093/bioadv/vbac016>
